==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Planilha de Tempo"
 ,"Planilhas de Tempo"

]
, "Account"
: "Conta"

, "Time Account (Number - Title)"
: "Contagem de Tempo (Número - Título)"

, "Billable"
: "Faturável"

, "Cleared in"
: "Limpo em"

, "Invoice"
: ""

, "Cleared"
: "Apuradas"

, "Date"
: "Data"

, "Start time"
: "Hora de início"

, "End time"
: ""

, "Duration"
: "Duração"

, "Description"
: "Descrição"

, "Type"
: ""

, "Time Account closed"
: "Contagem de Tempo fechada"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: "Contrato"

, "Title"
: "Título"

, "Number"
: "Número"

, "Price"
: ""

, "Status"
: "Situação"

, "Billed"
: "Faturado"

, "Cleared at"
: ""

, "Booking deadline"
: "Prazo de reserva"

, "Responsible"
: ""

, "Cost Center"
: "Centro de Custo"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Contagem de Tempo"
 ,"Contagens de Tempo"

]
, "Time Account - Status"
: "Contagem de Tempo - Situação"

, "closed"
: "fechado"

, "open"
: "aberto"

, "Not a valid time"
: "Hora inválida"

, "Time Account - Billed"
: "Hora da Conta - Faturado"

, "not yet billed"
: "não faturado ainda"

, "to bill"
: "a faturar"

, "billed"
: "faturado"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Autorizado em"

, "Select Time Account..."
: "Selecione a Contagem de Tempo..."

, "Start"
: "Início"

, "not set"
: "não configurado"

, "End"
: ""

, "Enter description..."
: "Digite a descrição..."

, "Need for Clarification"
: ""

, "Failed"
: "Falhou"

, "Could not save {0}."
: "Não pode ser salvo {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Prazo de reserva para esta Contagem de Tempo foi excedido."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Próprio Livro"

, "The grant to add Timesheets to this Timeaccount"
: "O privilégio para adicionar Planilhas de Tempo para esta Contagem de Tempo"

, "View All"
: "Ver Tudo"

, "The grant to view Timesheets of other users"
: "O privilégio para mostrar as Planilhas de Tempo de outros usuários"

, "Book All"
: "Reservar Todos"

, "The grant to add Timesheets for other users"
: "O privilégio para adicionar Planilhas de Tempo para outros usuários"

, "Manage Clearing"
: "Gerenciar Ajustes"

, "The grant to manage clearing of Timesheets"
: "O privilégio para gerenciar ajuste de Planilhas de Tempo"

, "without contract"
: "sem contrato"

, "without responsible"
: ""

, "timeframe"
: "prazo"

, "summary"
: "resumo"

, "Total Timesheets"
: "Planilhas de Tempo Totais"

, "Billable Timesheets"
: "Planilhas de Tempo Faturáveis"

, "Total Time"
: "Tempo Total"

, "Time of Billable Timesheets"
: "Planilhas de Tempo Faturáveis"

, "Detail"
: "Detalhe"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportar Planilhas de Tempo"

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CSV"

, "Export as ..."
: "Exportar como ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidade"

, "Unit Price"
: "Unidade de Preço"

, "Budget"
: "Orçamento"

, "Timesheets are billable"
: "Planilhas de Tempo estão faturadas"

, "Access"
: "Acesso"

, "Permissions"
: "Permissões"

, "Show closed"
: "Exibição não disponível"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Configuração para exportar planilhas de tempo em formato ODS"

, "Use this configuration for the timesheet ODS export."
: "Usar esta configuração para exportar planilhas de tempo no formato ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "padrão"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "nenhum"

, "last week"
: "última semana"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Gerenciar planilhas de tempo"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Adicionar, editar ou apagar planilhas de tempo (incluindo todos os privilégios das planilhas)"

, "Add timeaccounts"
: "Adicionar planilhas de tempo"

, "Manage shared timeaccount favorites"
: "Gerenciar contagem de tempo compartilhado de favoritos"

, "Create or update shared timeaccount favorites"
: "Criar ou atualizar contagem de tempo compartilhadas favoritas"

, "Manage shared timesheet favorites"
: "Gerenciar planilhas favoritas compartilhadas"

, "Create or update shared timesheet favorites"
: "Criar ou atualizar planilhas compartilhadas favoritas"

, "My Timesheets today"
: "Minhas Planilhas de tempo hoje"

, "My Timesheets this week"
: "Minhas Planilhas de tempo esta semana"

, "My Timesheets last week"
: "Minhas Planilhas de tempo da última semana"

, "My Timesheets this month"
: "Minhas Planilhas de tempo deste mes"

, "My Timesheets last month"
: "Minhas Planilhas de tempo do último mes"

, "Timeaccounts to bill"
: "Contagem de tempo para faturar"

, "Timeaccounts not yet billed"
: "Contagem de tempo ainda não faturada"

, "Timeaccounts already billed"
: "Contagem de tempo já faturada"

, "Timetracker"
: "Prazo"

, "Timesheet"
: "Planilha de Tempo"

, "Timeaccount"
: ""

, "Time Account"
: "Contagem de Tempo"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "prazo"

, "summary"
: "resumo"

, "Total Timesheets"
: "Planilhas de Tempo Totais"

, "Billable Timesheets"
: "Planilhas de Tempo Faturáveis"

, "Total Time"
: "Tempo Total"

, "Time of Billable Timesheets"
: "Planilhas de Tempo Faturáveis"

, "Description"
: "Descrição"

, "Detail"
: "Detalhe"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportar Planilhas de Tempo"

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CSV"

, "Export as ..."
: "Exportar como ..."

, "Timesheet, Timesheets"
: [
  "Planilha de Tempo"
 ,"Planilhas de Tempo"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Falhou"

, "Could not save {0}."
: "Não pode ser salvo {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Prazo de reserva para esta Contagem de Tempo foi excedido."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Contrato"

, "without contract"
: "sem contrato"

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidade"

, "Unit Price"
: "Unidade de Preço"

, "Factor"
: ""

, "Budget"
: "Orçamento"

, "Status"
: "Situação"

, "closed"
: "fechado"

, "open"
: "aberto"

, "Cleared In"
: "Autorizado em"

, "Cleared at"
: ""

, "Cost Center"
: "Centro de Custo"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Planilhas de Tempo estão faturadas"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Contagem de Tempo"
 ,"Contagens de Tempo"

]
, "Number"
: "Número"

, "Title"
: "Título"

, "Access"
: "Acesso"

, "Permissions"
: "Permissões"

, "Time Account - Billed"
: "Hora da Conta - Faturado"

, "not yet billed"
: "não faturado ainda"

, "to bill"
: "a faturar"

, "billed"
: "faturado"

, "Time Account - Status"
: "Contagem de Tempo - Situação"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Próprio Livro"

, "The grant to add Timesheets to this Timeaccount"
: "O privilégio para adicionar Planilhas de Tempo para esta Contagem de Tempo"

, "View All"
: "Ver Tudo"

, "The grant to view Timesheets of other users"
: "O privilégio para mostrar as Planilhas de Tempo de outros usuários"

, "Book All"
: "Reservar Todos"

, "The grant to add Timesheets for other users"
: "O privilégio para adicionar Planilhas de Tempo para outros usuários"

, "Manage Clearing"
: "Gerenciar Ajustes"

, "The grant to manage clearing of Timesheets"
: "O privilégio para gerenciar ajuste de Planilhas de Tempo"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Exibição não disponível"

, "Timesheets ODS export configuration"
: "Configuração para exportar planilhas de tempo em formato ODS"

, "Use this configuration for the timesheet ODS export."
: "Usar esta configuração para exportar planilhas de tempo no formato ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "padrão"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "nenhum"

, "last week"
: "última semana"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Limpo em"

, "Billed"
: "Faturado"

, "Booking deadline"
: "Prazo de reserva"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Conta"

, "Time Account (Number - Title)"
: "Contagem de Tempo (Número - Título)"

, "Billable"
: "Faturável"

, "Cleared"
: "Apuradas"

, "Date"
: "Data"

, "Start time"
: "Hora de início"

, "End time"
: ""

, "Duration"
: "Duração"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Contagem de Tempo fechada"

, "Timetracker"
: "Prazo"

, "Timeaccounts to bill"
: "Contagem de tempo para faturar"

, "Timeaccounts not yet billed"
: "Contagem de tempo ainda não faturada"

, "Timeaccounts already billed"
: "Contagem de tempo já faturada"

, "My Timesheets today"
: "Minhas Planilhas de tempo hoje"

, "My Timesheets this week"
: "Minhas Planilhas de tempo esta semana"

, "My Timesheets last week"
: "Minhas Planilhas de tempo da última semana"

, "My Timesheets this month"
: "Minhas Planilhas de tempo deste mes"

, "My Timesheets last month"
: "Minhas Planilhas de tempo do último mes"

, "Manage timeaccounts"
: "Gerenciar planilhas de tempo"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Adicionar, editar ou apagar planilhas de tempo (incluindo todos os privilégios das planilhas)"

, "Add timeaccounts"
: "Adicionar planilhas de tempo"

, "Manage shared timeaccount favorites"
: "Gerenciar contagem de tempo compartilhado de favoritos"

, "Create or update shared timeaccount favorites"
: "Criar ou atualizar contagem de tempo compartilhadas favoritas"

, "Manage shared timesheet favorites"
: "Gerenciar planilhas favoritas compartilhadas"

, "Create or update shared timesheet favorites"
: "Criar ou atualizar planilhas compartilhadas favoritas"






, "Timesheet"
: "Planilha de Tempo"

, "Timeaccount"
: ""

, "Time Account"
: "Contagem de Tempo"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
